""" 

Context : SRP
Module  : FITS
Version : 1.0.7
Author  : Stefano Covino
Date    : 04/11/2014
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (25/03/2014) First version.
        : (16/05/2014) V. 1.0.1b1.
        : (16/07/2014) V. 1.0.1b2.
        : (21/07/2014) V. 1.0.1b3.
        : (06/08/2014) V. 1.0.1.
        : (13/08/2014) V. 1.0.2b1.
        : (27/10/2014) V. 1.1.0b1.
        : (29/10/2014) V. 1.1.0b2.
        : (30/10/2014) V. 1.1.0b3.
        : (04/11/2014) V. 1.1.0.
"""

__version__ = '1.1.0'



#__all__ =  ['FITS',]





